==> openshift-client-5.5.0-sources.jar: io/fabric8/openshift/client/handlers/cloudcredential/CredentialsRequestHandler.java <==

                                                    

package io.fabric8.openshift.client.handlers.cloudcredential;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.cloudcredential.CredentialsRequestOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequest;
import io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class CredentialsRequestHandler implements ResourceHandler<CredentialsRequest, CredentialsRequestBuilder> {

  @Override
  public String getKind() {
    return CredentialsRequest.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "cloudcredential.openshift.io/v1";
    }

  @Override
  public CredentialsRequest create(OkHttpClient client, Config config, String namespace, CredentialsRequest item, boolean dryRun) {
    return new CredentialsRequestOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public CredentialsRequest replace(OkHttpClient client, Config config, String namespace, CredentialsRequest item, boolean dryRun) {
    return new CredentialsRequestOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public CredentialsRequest reload(OkHttpClient client, Config config, String namespace, CredentialsRequest item) {
    return new CredentialsRequestOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public CredentialsRequestBuilder edit(CredentialsRequest item) {
    return new CredentialsRequestBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, CredentialsRequest item, boolean dryRun) {
    return new CredentialsRequestOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, CredentialsRequest item, Watcher<CredentialsRequest> watcher) {
    return new CredentialsRequestOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, CredentialsRequest item, String resourceVersion, Watcher<CredentialsRequest> watcher) {
    return new CredentialsRequestOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, CredentialsRequest item, ListOptions options, Watcher<CredentialsRequest> watcher) {
  return new CredentialsRequestOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public CredentialsRequest waitUntilReady(OkHttpClient client, Config config, String namespace, CredentialsRequest item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new CredentialsRequestOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public CredentialsRequest waitUntilCondition(OkHttpClient client, Config config, String namespace, CredentialsRequest item, Predicate<CredentialsRequest> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new CredentialsRequestOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-5.6.0-sources.jar: io/fabric8/openshift/client/handlers/cloudcredential/CredentialsRequestHandler.java <==

                                                    

package io.fabric8.openshift.client.handlers.cloudcredential;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.openshift.client.dsl.internal.cloudcredential.CredentialsRequestOperationsImpl;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequest;
import io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestBuilder;

public class CredentialsRequestHandler implements ResourceHandler<CredentialsRequest, CredentialsRequestBuilder> {

  @Override
  public String getKind() {
    return CredentialsRequest.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "cloudcredential.openshift.io/v1";
    }

  @Override
  public CredentialsRequestBuilder edit(CredentialsRequest item) {
    return new CredentialsRequestBuilder(item);
  }

  @Override
  public Resource<CredentialsRequest> resource(OkHttpClient client, Config config, String namespace, CredentialsRequest item) {
    return new CredentialsRequestOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName());
  }

}
